==> activemq_5.15.11.orig.tar.xz: activemq-activemq-5.15.11/activemq-client/src/main/java/org/apache/activemq/wireformat/WireFormat.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.activemq.wireformat;

import java.io.DataInput;
import java.io.DataOutput;
import java.io.IOException;

import org.apache.activemq.util.ByteSequence;


/**
 * Provides a mechanism to marshal commands into and out of packets
 * or into and out of streams, Channels and Datagrams.
 *
 * 
 */
public interface WireFormat {

    /**
     * Packet based marshaling 
     */
    ByteSequence marshal(Object command) throws IOException;
    
    /**
     * Packet based un-marshaling 
     */
    Object unmarshal(ByteSequence packet) throws IOException;

    /**
     * Stream based marshaling 
     */
    void marshal(Object command, DataOutput out) throws IOException;
    
    /**
     * Packet based un-marshaling 
     */
    Object unmarshal(DataInput in) throws IOException;
    
    /**
     * @param the version of the wire format
     */
    void setVersion(int version);
    
    /**
     * @return the version of the wire format
     */
    int getVersion();
    
}

==> activemq_5.17.6+dfsg.orig.tar.xz: activemq-activemq-5.17.6/activemq-client/src/main/java/org/apache/activemq/wireformat/WireFormat.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.activemq.wireformat;

import java.io.DataInput;
import java.io.DataOutput;
import java.io.IOException;

import org.apache.activemq.util.ByteSequence;


/**
 * Provides a mechanism to marshal commands into and out of packets
 * or into and out of streams, Channels and Datagrams.
 *
 * 
 */
public interface WireFormat {

    /**
     * Packet based marshaling 
     */
    ByteSequence marshal(Object command) throws IOException;
    
    /**
     * Packet based un-marshaling 
     */
    Object unmarshal(ByteSequence packet) throws IOException;

    /**
     * Stream based marshaling 
     */
    void marshal(Object command, DataOutput out) throws IOException;
    
    /**
     * Packet based un-marshaling 
     */
    Object unmarshal(DataInput in) throws IOException;
    
    /**
     * @param version the version of the wire format
     */
    void setVersion(int version);
    
    /**
     * @return the version of the wire format
     */
    int getVersion();
    
}
